summaryrefslogtreecommitdiff
path: root/bootstrap
diff options
context:
space:
mode:
authorAndreas Schneider <asn@samba.org>2019-05-06 10:33:01 +0200
committerAndrew Bartlett <abartlet@samba.org>2019-05-07 00:11:25 +0000
commit3c47066e067dd23e46435e5b3f8c8801a6d81fb7 (patch)
tree7cbabb4d518e2feea849dd7397f05088b18e7957 /bootstrap
parent05791f40a6e78e628ec4ab2fb0e13b2c7fbb1b78 (diff)
downloadsamba-3c47066e067dd23e46435e5b3f8c8801a6d81fb7.tar.gz
bootstrap: Move to python 3.6 on CentOS
Signed-off-by: Andreas Schneider <asn@samba.org> Reviewed-by: Andrew Bartlett <abartlet@samba.org>
Diffstat (limited to 'bootstrap')
-rw-r--r--bootstrap/config.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/bootstrap/config.py b/bootstrap/config.py
index 7870fec1e23..c526b38205a 100644
--- a/bootstrap/config.py
+++ b/bootstrap/config.py
@@ -221,7 +221,7 @@ yum install -y \
yum clean all
if [ ! -f /usr/bin/python3 ]; then
- ln -sf /usr/bin/python3.4 /usr/bin/python3
+ ln -sf /usr/bin/python3.6 /usr/bin/python3
fi
"""
@@ -432,8 +432,8 @@ RPM_DISTS = {
'bootstrap': YUM_BOOTSTRAP,
'replace': {
'lsb-release': 'redhat-lsb',
- 'python3': 'python34',
- 'python3-devel': 'python34-devel',
+ 'python3': 'python36',
+ 'python3-devel': 'python36-devel',
'python2-gpg': 'pygpgme',
'python3-gpg': '', # no python3-gpg yet
'@development-tools': '"@Development Tools"', # add quotes
@@ -455,11 +455,11 @@ RPM_DISTS = {
'bootstrap': YUM_BOOTSTRAP,
'replace': {
'lsb-release': 'redhat-lsb',
- 'python3': 'python34',
- 'python3-devel': 'python34-devel',
+ 'python3': 'python36',
+ 'python3-devel': 'python36-devel',
# although python36-devel is available
# after epel-release installed
# however, all other python3 pkgs are still python34-ish
'python2-gpg': 'pygpgme',
'python3-gpg': '', # no python3-gpg yet
'@development-tools': '"@Development Tools"', # add quotes
@@ -455,11 +455,11 @@ RPM_DISTS = {
# although python36-devel is available
# after epel-release installed
- # however, all other python3 pkgs are still python34-ish
+ # however, all other python3 pkgs are still python36-ish
'python2-gpg': 'pygpgme',
'python3-gpg': '', # no python3-gpg yet